package com.predic8.tutorial.activities;

import android.app.Activity;
import android.content.Context;
import android.graphics.BitmapFactory;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.FrameLayout;

import com.predic8.tutorial.R;
import com.predic8.tutorial.model.Plane;
import com.predic8.tutorial.views.BackgroundView;
import com.predic8.tutorial.views.PlaneView;

public class Main extends Activity implements SensorEventListener{

	private BackgroundView bgv;

	private SensorManager mSensorManager;
	private Sensor mAccelerometer;

	private PlaneView pv;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		mSensorManager = (SensorManager) getSystemService(Context.SENSOR_SERVICE);
		mAccelerometer = mSensorManager.getDefaultSensor(Sensor.TYPE_ORIENTATION);

		bgv = new BackgroundView(this);

		FrameLayout fl = new FrameLayout(this);
		FrameLayout.LayoutParams lp = new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT,ViewGroup.LayoutParams.MATCH_PARENT);
		fl.setLayoutParams(lp);

		pv = new PlaneView(this, new Plane(0, 0,BitmapFactory.decodeResource(getResources(), R.drawable.plane_icon)), bgv.getBackgroundModel());

		fl.addView(bgv);
		fl.addView(pv);

		setContentView(fl);
	}

	@Override
	protected void onResume() {
		super.onResume();
		getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
		mSensorManager.registerListener(this, mAccelerometer, SensorManager.SENSOR_DELAY_GAME);
		bgv.resume();
	}

	@Override
	protected void onPause() {
		super.onPause();
		mSensorManager.unregisterListener(this);
		bgv.pause();
	}

	public float[] getPlanePosition(float y, float z, float maxAngle) {
		float[] coordinates = new float[2];

		coordinates[0] = (pv.getWidth()/2)+((y/maxAngle)*pv.getWidth()/2)-(pv.getPlane().getImage().getWidth()/2);
		coordinates[1] = (pv.getHeight()/2)+((z/maxAngle)*pv.getHeight()/2)-(pv.getPlane().getImage().getHeight()/2);

		return coordinates;
	}

	@Override
	public void onAccuracyChanged(Sensor s, int acc) {
		// TODO Auto-generated method stub

	}

	@Override
	public void onSensorChanged(SensorEvent event) {
	    if (event.sensor.getType() == Sensor.TYPE_ORIENTATION){
	        float y = - event.values[1];
	        float z = event.values[2]-45;

	        float maxAngle = 30;
	        
	        if (y > maxAngle)
	          y = maxAngle;
	        if (y < -maxAngle)
	          y = -maxAngle;
	       
	        if (z > maxAngle)
	          z = maxAngle;
	        if (z < -maxAngle)
	          z = -maxAngle;

			float[] coords= getPlanePosition(y,z,maxAngle);

			int bgBaseSpeed = 12;
			 
			int bgSpeed = (int) (bgBaseSpeed + ((24)*(y/maxAngle)));
			bgv.getBackgroundModel().setSpeed(bgSpeed < 3 ? 3 : bgSpeed);
			
			pv.getPlane().setPosition(coords);
			pv.invalidate();

		}
	}

}
